History
=======

0.6.4 (2022-01-24)
------------------
- Added: Bayless and Abrahamson (2019)

0.6.3 (2021-12-08)
--------------------
- Fixed: error in ASK14 on a7 term

0.6.2 (2021-10-19)
--------------------
- Changed: Move site amplification to static functions on some GMPEs

0.6.1 (2020-06-03)
------------------
- Added Coppersmith & Bommer (2014) model for Hanford
- Factored tests

0.6.0 (2019-08-12)
------------------
- Added Abrahamson, Gregor, Addo (2014)
- Added Abrahamson & Gulerce (2011)
- Added conditional mean spectra models.
- Added Scenario objects.
- Added typing for all classes.

0.4.0 (2016-04-08)
------------------

-  Added Hermkes et al. (2014).
-  Improved documentation.
-  Added Baker & Jayaram (2008), Kishida (2017)

.. _section-1:

0.3.2 (2016-03-30)
------------------

-  Nothing changed yet.

.. _section-2:

0.3.1 (2016-03-30)
------------------

-  First release on PyPI.
